@@ -35,6 +35,7 @@
 #include "gnome-run.h"
 #include "multiscreen-stuff.h"
 #include "panel-marshal.h"
+#include "panel-stock-icons.h"
 
 #define ICON_SIZE 20
 #define FOOBAR_MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_KDE_SUB | MAIN_MENU_DISTRIBUTION_SUB)
@@ -54,6 +55,8 @@ static gboolean foobar_leave_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
 static gboolean foobar_enter_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
+static gboolean foobar_widget_popup_panel_menu (FoobarWidget *foobar);
+
 static void append_task_menu (FoobarWidget *foo, GtkMenuShell *menu_bar);
 static void setup_task_menu (FoobarWidget *foo);
 
@@ -61,6 +64,11 @@ static GList *foobars = NULL;
 
 static GtkWindowClass *foobar_widget_parent_class = NULL;
 
+enum {
+	POPUP_PANEL_MENU_SIGNAL,
+	WIDGET_LAST_SIGNAL
+};
+
 GType
 foobar_widget_get_type (void)
 {
@@ -87,11 +95,18 @@ foobar_widget_get_type (void)
 	return object_type;
 }
 
+static guint foobar_widget_signals [WIDGET_LAST_SIGNAL] = { 0 };
+
 static void
 foobar_widget_class_init (FoobarWidgetClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+	GtkBindingSet  *binding_set;
+
+	binding_set = gtk_binding_set_by_class (klass);
+
+	klass->popup_panel_menu = foobar_widget_popup_panel_menu;
 
 	object_class->destroy = foobar_widget_destroy;
 
@@ -106,6 +121,20 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 			     "GtkMenuBar::internal-padding = 0\n"
 			     "}\n"
 			     "widget \"*.panel-foobar-menubar\" style \"panel-foobar-menubar-style\"");
+
+	foobar_widget_signals [POPUP_PANEL_MENU_SIGNAL] =
+		g_signal_new ("popup_panel_menu",
+			     G_TYPE_FROM_CLASS (object_class),
+			     G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			     G_STRUCT_OFFSET (FoobarWidgetClass, popup_panel_menu),
+			     NULL,
+			     NULL,
+			     panel_marshal_BOOLEAN__VOID,
+			     G_TYPE_BOOLEAN,
+			     0);
+
+	gtk_binding_entry_add_signal (binding_set, GDK_F10, GDK_CONTROL_MASK,
+				     "popup_panel_menu", 0);
 }
 
 static gboolean
@@ -158,8 +187,9 @@ append_actions_menu (GtkWidget *menu_bar)
 
 	menu = panel_menu_new ();
 
-	item = pixmap_menu_item_new (_("Run Program..."), "gnome-run.png",
-				     FALSE /* force_image */);
+	item = stock_menu_item_new (_("Run Program..."),
+				    PANEL_STOCK_RUN,
+				    FALSE);
 	gtk_tooltips_set_tip (panel_tooltips, item,
 			      _("Run applications, if you know the "
 				"correct command to type in"),
@@ -169,8 +199,10 @@ append_actions_menu (GtkWidget *menu_bar)
 			  G_CALLBACK (show_run_dialog), 0);
 
 	if (panel_is_program_in_path  ("gnome-search-tool")) {
-		item = pixmap_menu_item_new (
-				_("Search for Files..."), "gnome-searchtool.png", FALSE);
+		item = stock_menu_item_new (
+				_("Search for Files..."),
+				PANEL_STOCK_SEARCHTOOL,
+				FALSE);
 
 		gtk_tooltips_set_tip (panel_tooltips, item,
 				      _("Find files, folders, and documents "
@@ -183,7 +215,9 @@ append_actions_menu (GtkWidget *menu_bar)
 	}
 
 	if (panel_is_program_in_path ("gnome-panel-screenshot")) {
-		item = pixmap_menu_item_new (_("Screenshot..."), "gnome-screenshot.png", FALSE);
+		item = stock_menu_item_new (_("Screenshot..."),
+					    PANEL_STOCK_SCREENSHOT,
+					    FALSE);
 		gtk_tooltips_set_tip (panel_tooltips, item,
 			      	      _("Take a screenshot of your desktop"),
 			              NULL);
@@ -196,9 +230,9 @@ append_actions_menu (GtkWidget *menu_bar)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	if (panel_is_program_in_path  ("xscreensaver")) {
-		item = pixmap_menu_item_new (_("Lock Screen"), 
-					     "gnome-lockscreen.png",
-					     FALSE /* force_image */);
+		item = stock_menu_item_new (_("Lock Screen"), 
+					    PANEL_STOCK_LOCKSCREEN, 
+					    FALSE);
 		gtk_tooltips_set_tip (panel_tooltips, item,
 				      _("Protect your computer from "
 					"unauthorized use"),
@@ -209,8 +243,9 @@ append_actions_menu (GtkWidget *menu_bar)
 		setup_internal_applet_drag(item, "LOCK:NEW");
 	}
 
-	item = pixmap_menu_item_new (_("Log Out"), "gnome-term-night.png",
-				     FALSE /* force_image */);
+	item = stock_menu_item_new (_("Log Out"),
+				    PANEL_STOCK_LOGOUT,
+				    FALSE);
 	gtk_tooltips_set_tip (panel_tooltips, item,
 			      _("Quit from the GNOME desktop"),
 			      NULL);
@@ -644,6 +679,7 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *align;
+	GtkWidget *image;
 	char      *path;
 
 	window = GTK_WINDOW (foo);
@@ -675,7 +711,7 @@ foobar_widget_instance_init (FoobarWidget *foo)
 				       NULL, FALSE, FALSE, FALSE, NULL);
 	PANEL_WIDGET (foo->panel)->panel_parent = GTK_WIDGET (foo);
 	PANEL_WIDGET (foo->panel)->drop_widget = GTK_WIDGET (foo);
-	add_atk_name_desc (foo->panel, _("Menu Panel"), _("GNOME Menu Panel"));
+	panel_set_atk_name_desc (foo->panel, _("Menu Panel"), _("GNOME Menu Panel"));
 
 	foo->ebox = gtk_event_box_new ();
 	foo->hbox = gtk_hbox_new (FALSE, 0);
@@ -694,10 +730,12 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	menu_bar = gtk_menu_bar_new ();	
 	gtk_widget_set_name (menu_bar,
 			     "panel-foobar-menubar");
-	
-	menuitem = pixmap_menu_item_new (_("Applications"),
-					 "gnome-logo-icon-transparent.png",
-					 TRUE /* force_image */);
+
+	menuitem = gtk_image_menu_item_new_with_label (_("Applications"));
+	image = gtk_image_new_from_stock (
+			PANEL_STOCK_GNOME_LOGO,
+			panel_foobar_icon_get_size ()),
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 
 	menu = create_root_menu (
 			NULL, PANEL_WIDGET (foo->panel),
@@ -980,3 +1018,14 @@ foobar_widget_redo_window(FoobarWidget *foo)
 
 	gtk_widget_map(widget);
 }
+
+static gboolean
+foobar_widget_popup_panel_menu (FoobarWidget *foobar)
+{
+ 	gboolean retval;
+
+	g_signal_emit_by_name (foobar->panel, "popup_menu", &retval);
+
+	return retval;
+}
+
